@@ -8,12 +8,9 @@ package Getopt::Alt::Exception;
 
 use Moose;
 use version;
-use Carp;
-use Data::Dumper qw/Dumper/;
-use English qw/ -no_match_vars /;
 use overload '""' => sub { shift->message };
 
-our $VERSION = version->new('0.1.3');
+our $VERSION = version->new('0.1.4');
 
 has message => (
     is      => 'rw',
@@ -42,7 +39,7 @@ Getopt::Alt::Exception - I have forgotten where I was going with this
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt::Exception version 0.1.3.
+This documentation refers to Getopt::Alt::Exception version 0.1.4.
 
 
 =head1 SYNOPSIS
